# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'ui5/wifisetupdialog_base.ui'
#
# Created by: PyQt5 UI code generator 5.4.2
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Dialog(object):
    def setupUi(self, Dialog):
        Dialog.setObjectName("Dialog")
        Dialog.setWindowModality(QtCore.Qt.ApplicationModal)
        Dialog.resize(700, 500)
        self.gridlayout = QtWidgets.QGridLayout(Dialog)
        self.gridlayout.setObjectName("gridlayout")
        self.StackedWidget = QtWidgets.QStackedWidget(Dialog)
        self.StackedWidget.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.StackedWidget.setObjectName("StackedWidget")
        self.DiscoveryPage = QtWidgets.QWidget()
        self.DiscoveryPage.setObjectName("DiscoveryPage")
        self.gridlayout1 = QtWidgets.QGridLayout(self.DiscoveryPage)
        self.gridlayout1.setObjectName("gridlayout1")
        self.label = QtWidgets.QLabel(self.DiscoveryPage)
        font = QtGui.QFont()
        font.setPointSize(16)
        self.label.setFont(font)
        self.label.setObjectName("label")
        self.gridlayout1.addWidget(self.label, 0, 0, 1, 3)
        self.line = QtWidgets.QFrame(self.DiscoveryPage)
        self.line.setFrameShape(QtWidgets.QFrame.HLine)
        self.line.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line.setObjectName("line")
        self.gridlayout1.addWidget(self.line, 1, 0, 1, 3)
        self.MainTitleLabel = QtWidgets.QLabel(self.DiscoveryPage)
        self.MainTitleLabel.setWordWrap(True)
        self.MainTitleLabel.setObjectName("MainTitleLabel")
        self.gridlayout1.addWidget(self.MainTitleLabel, 2, 0, 1, 3)
        spacerItem = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridlayout1.addItem(spacerItem, 3, 1, 1, 1)
        spacerItem1 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridlayout1.addItem(spacerItem1, 4, 0, 1, 1)
        self.Picture = QtWidgets.QLabel(self.DiscoveryPage)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.Picture.sizePolicy().hasHeightForWidth())
        self.Picture.setSizePolicy(sizePolicy)
        self.Picture.setMinimumSize(QtCore.QSize(396, 128))
        self.Picture.setMaximumSize(QtCore.QSize(396, 128))
        self.Picture.setText("")
        self.Picture.setObjectName("Picture")
        self.gridlayout1.addWidget(self.Picture, 4, 1, 1, 1)
        spacerItem2 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridlayout1.addItem(spacerItem2, 4, 2, 1, 1)
        spacerItem3 = QtWidgets.QSpacerItem(664, 61, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridlayout1.addItem(spacerItem3, 5, 0, 1, 3)
        self.hboxlayout = QtWidgets.QHBoxLayout()
        self.hboxlayout.setObjectName("hboxlayout")
        self.InfoIcon = QtWidgets.QLabel(self.DiscoveryPage)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.InfoIcon.sizePolicy().hasHeightForWidth())
        self.InfoIcon.setSizePolicy(sizePolicy)
        self.InfoIcon.setMinimumSize(QtCore.QSize(16, 16))
        self.InfoIcon.setMaximumSize(QtCore.QSize(16, 16))
        self.InfoIcon.setText("")
        self.InfoIcon.setObjectName("InfoIcon")
        self.hboxlayout.addWidget(self.InfoIcon)
        self.label_14 = QtWidgets.QLabel(self.DiscoveryPage)
        self.label_14.setWordWrap(True)
        self.label_14.setObjectName("label_14")
        self.hboxlayout.addWidget(self.label_14)
        self.gridlayout1.addLayout(self.hboxlayout, 6, 0, 1, 3)
        self.StackedWidget.addWidget(self.DiscoveryPage)
        self.page_2 = QtWidgets.QWidget()
        self.page_2.setObjectName("page_2")
        self.gridlayout2 = QtWidgets.QGridLayout(self.page_2)
        self.gridlayout2.setObjectName("gridlayout2")
        self.label_4 = QtWidgets.QLabel(self.page_2)
        font = QtGui.QFont()
        font.setPointSize(16)
        self.label_4.setFont(font)
        self.label_4.setObjectName("label_4")
        self.gridlayout2.addWidget(self.label_4, 0, 0, 1, 2)
        self.line_2 = QtWidgets.QFrame(self.page_2)
        self.line_2.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_2.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_2.setObjectName("line_2")
        self.gridlayout2.addWidget(self.line_2, 1, 0, 1, 3)
        self.DevicesTableWidget = QtWidgets.QTableWidget(self.page_2)
        self.DevicesTableWidget.setAlternatingRowColors(True)
        self.DevicesTableWidget.setSelectionMode(QtWidgets.QAbstractItemView.SingleSelection)
        self.DevicesTableWidget.setSelectionBehavior(QtWidgets.QAbstractItemView.SelectRows)
        self.DevicesTableWidget.setObjectName("DevicesTableWidget")
        self.DevicesTableWidget.setColumnCount(0)
        self.DevicesTableWidget.setRowCount(0)
        self.gridlayout2.addWidget(self.DevicesTableWidget, 2, 0, 1, 3)
        self.hboxlayout1 = QtWidgets.QHBoxLayout()
        self.hboxlayout1.setObjectName("hboxlayout1")
        self.DevicesFoundIcon = QtWidgets.QLabel(self.page_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.DevicesFoundIcon.sizePolicy().hasHeightForWidth())
        self.DevicesFoundIcon.setSizePolicy(sizePolicy)
        self.DevicesFoundIcon.setMinimumSize(QtCore.QSize(16, 16))
        self.DevicesFoundIcon.setMaximumSize(QtCore.QSize(16, 16))
        self.DevicesFoundIcon.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.DevicesFoundIcon.setText("")
        self.DevicesFoundIcon.setObjectName("DevicesFoundIcon")
        self.hboxlayout1.addWidget(self.DevicesFoundIcon)
        self.DevicesFoundLabel = QtWidgets.QLabel(self.page_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.DevicesFoundLabel.sizePolicy().hasHeightForWidth())
        self.DevicesFoundLabel.setSizePolicy(sizePolicy)
        self.DevicesFoundLabel.setWordWrap(True)
        self.DevicesFoundLabel.setObjectName("DevicesFoundLabel")
        self.hboxlayout1.addWidget(self.DevicesFoundLabel)
        self.gridlayout2.addLayout(self.hboxlayout1, 3, 0, 1, 1)
        spacerItem4 = QtWidgets.QSpacerItem(21, 28, QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Minimum)
        self.gridlayout2.addItem(spacerItem4, 3, 1, 1, 1)
        self.RefreshButton = QtWidgets.QPushButton(self.page_2)
        self.RefreshButton.setObjectName("RefreshButton")
        self.gridlayout2.addWidget(self.RefreshButton, 3, 2, 1, 1)
        self.StackedWidget.addWidget(self.page_2)
        self.page_3 = QtWidgets.QWidget()
        self.page_3.setObjectName("page_3")
        self.gridlayout3 = QtWidgets.QGridLayout(self.page_3)
        self.gridlayout3.setObjectName("gridlayout3")
        self.label_5 = QtWidgets.QLabel(self.page_3)
        font = QtGui.QFont()
        font.setPointSize(16)
        self.label_5.setFont(font)
        self.label_5.setObjectName("label_5")
        self.gridlayout3.addWidget(self.label_5, 0, 0, 1, 1)
        self.line_3 = QtWidgets.QFrame(self.page_3)
        self.line_3.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_3.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_3.setObjectName("line_3")
        self.gridlayout3.addWidget(self.line_3, 1, 0, 1, 1)
        self.groupBox_3 = QtWidgets.QGroupBox(self.page_3)
        self.groupBox_3.setObjectName("groupBox_3")
        self.gridlayout4 = QtWidgets.QGridLayout(self.groupBox_3)
        self.gridlayout4.setObjectName("gridlayout4")
        self.UndirectedRadioButton = QtWidgets.QRadioButton(self.groupBox_3)
        self.UndirectedRadioButton.setChecked(True)
        self.UndirectedRadioButton.setObjectName("UndirectedRadioButton")
        self.gridlayout4.addWidget(self.UndirectedRadioButton, 0, 0, 1, 3)
        self.DirectedRadioButton = QtWidgets.QRadioButton(self.groupBox_3)
        self.DirectedRadioButton.setObjectName("DirectedRadioButton")
        self.gridlayout4.addWidget(self.DirectedRadioButton, 1, 0, 1, 2)
        self.SSIDLineEdit = QtWidgets.QLineEdit(self.groupBox_3)
        self.SSIDLineEdit.setEnabled(False)
        self.SSIDLineEdit.setObjectName("SSIDLineEdit")
        self.gridlayout4.addWidget(self.SSIDLineEdit, 1, 2, 1, 1)
        self.SearchPushButton = QtWidgets.QPushButton(self.groupBox_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Maximum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.SearchPushButton.sizePolicy().hasHeightForWidth())
        self.SearchPushButton.setSizePolicy(sizePolicy)
        self.SearchPushButton.setObjectName("SearchPushButton")
        self.gridlayout4.addWidget(self.SearchPushButton, 2, 0, 1, 1)
        spacerItem5 = QtWidgets.QSpacerItem(521, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridlayout4.addItem(spacerItem5, 2, 1, 1, 2)
        self.gridlayout3.addWidget(self.groupBox_3, 2, 0, 1, 1)
        self.SelectSSIDGroupBox = QtWidgets.QGroupBox(self.page_3)
        self.SelectSSIDGroupBox.setCheckable(False)
        self.SelectSSIDGroupBox.setObjectName("SelectSSIDGroupBox")
        self.gridlayout5 = QtWidgets.QGridLayout(self.SelectSSIDGroupBox)
        self.gridlayout5.setObjectName("gridlayout5")
        spacerItem6 = QtWidgets.QSpacerItem(421, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridlayout5.addItem(spacerItem6, 0, 0, 1, 2)
        self.ShowExtendedCheckBox = QtWidgets.QCheckBox(self.SelectSSIDGroupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Maximum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.ShowExtendedCheckBox.sizePolicy().hasHeightForWidth())
        self.ShowExtendedCheckBox.setSizePolicy(sizePolicy)
        self.ShowExtendedCheckBox.setObjectName("ShowExtendedCheckBox")
        self.gridlayout5.addWidget(self.ShowExtendedCheckBox, 0, 2, 1, 1)
        self.NetworksTableWidget = QtWidgets.QTableWidget(self.SelectSSIDGroupBox)
        self.NetworksTableWidget.setAlternatingRowColors(True)
        self.NetworksTableWidget.setSelectionMode(QtWidgets.QAbstractItemView.SingleSelection)
        self.NetworksTableWidget.setSelectionBehavior(QtWidgets.QAbstractItemView.SelectRows)
        self.NetworksTableWidget.setVerticalScrollMode(QtWidgets.QAbstractItemView.ScrollPerItem)
        self.NetworksTableWidget.setHorizontalScrollMode(QtWidgets.QAbstractItemView.ScrollPerPixel)
        self.NetworksTableWidget.setObjectName("NetworksTableWidget")
        self.NetworksTableWidget.setColumnCount(0)
        self.NetworksTableWidget.setRowCount(0)
        self.gridlayout5.addWidget(self.NetworksTableWidget, 1, 0, 1, 3)
        self.NetworksFoundIcon = QtWidgets.QLabel(self.SelectSSIDGroupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.NetworksFoundIcon.sizePolicy().hasHeightForWidth())
        self.NetworksFoundIcon.setSizePolicy(sizePolicy)
        self.NetworksFoundIcon.setMinimumSize(QtCore.QSize(16, 16))
        self.NetworksFoundIcon.setMaximumSize(QtCore.QSize(16, 16))
        self.NetworksFoundIcon.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.NetworksFoundIcon.setText("")
        self.NetworksFoundIcon.setObjectName("NetworksFoundIcon")
        self.gridlayout5.addWidget(self.NetworksFoundIcon, 2, 0, 1, 1)
        self.NetworksFoundLabel = QtWidgets.QLabel(self.SelectSSIDGroupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.NetworksFoundLabel.sizePolicy().hasHeightForWidth())
        self.NetworksFoundLabel.setSizePolicy(sizePolicy)
        self.NetworksFoundLabel.setWordWrap(True)
        self.NetworksFoundLabel.setObjectName("NetworksFoundLabel")
        self.gridlayout5.addWidget(self.NetworksFoundLabel, 2, 1, 1, 2)
        self.gridlayout3.addWidget(self.SelectSSIDGroupBox, 3, 0, 1, 1)
        self.StackedWidget.addWidget(self.page_3)
        self.page_5 = QtWidgets.QWidget()
        self.page_5.setObjectName("page_5")
        self.gridlayout6 = QtWidgets.QGridLayout(self.page_5)
        self.gridlayout6.setObjectName("gridlayout6")
        self.label_15 = QtWidgets.QLabel(self.page_5)
        font = QtGui.QFont()
        font.setPointSize(16)
        self.label_15.setFont(font)
        self.label_15.setObjectName("label_15")
        self.gridlayout6.addWidget(self.label_15, 0, 0, 1, 2)
        self.line_4 = QtWidgets.QFrame(self.page_5)
        self.line_4.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_4.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_4.setObjectName("line_4")
        self.gridlayout6.addWidget(self.line_4, 1, 0, 1, 2)
        self.hboxlayout2 = QtWidgets.QHBoxLayout()
        self.hboxlayout2.setObjectName("hboxlayout2")
        self.label_3 = QtWidgets.QLabel(self.page_5)
        self.label_3.setObjectName("label_3")
        self.hboxlayout2.addWidget(self.label_3)
        self.SSIDLabel = QtWidgets.QLabel(self.page_5)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.SSIDLabel.sizePolicy().hasHeightForWidth())
        self.SSIDLabel.setSizePolicy(sizePolicy)
        self.SSIDLabel.setObjectName("SSIDLabel")
        self.hboxlayout2.addWidget(self.SSIDLabel)
        self.StrengthIcon = QtWidgets.QLabel(self.page_5)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.StrengthIcon.sizePolicy().hasHeightForWidth())
        self.StrengthIcon.setSizePolicy(sizePolicy)
        self.StrengthIcon.setMinimumSize(QtCore.QSize(34, 20))
        self.StrengthIcon.setMaximumSize(QtCore.QSize(34, 20))
        self.StrengthIcon.setText("")
        self.StrengthIcon.setObjectName("StrengthIcon")
        self.hboxlayout2.addWidget(self.StrengthIcon)
        self.gridlayout6.addLayout(self.hboxlayout2, 2, 0, 1, 2)
        spacerItem7 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridlayout6.addItem(spacerItem7, 3, 1, 1, 1)
        self.groupBox = QtWidgets.QGroupBox(self.page_5)
        self.groupBox.setObjectName("groupBox")
        self.gridlayout7 = QtWidgets.QGridLayout(self.groupBox)
        self.gridlayout7.setObjectName("gridlayout7")
        self.WEPRadioButton = ReadOnlyRadioButton(self.groupBox)
        self.WEPRadioButton.setObjectName("WEPRadioButton")
        self.gridlayout7.addWidget(self.WEPRadioButton, 0, 0, 1, 1)
        self.WPARadioButton = ReadOnlyRadioButton(self.groupBox)
        self.WPARadioButton.setObjectName("WPARadioButton")
        self.gridlayout7.addWidget(self.WPARadioButton, 1, 0, 1, 1)
        self.gridlayout6.addWidget(self.groupBox, 4, 0, 1, 2)
        self.groupBox_2 = QtWidgets.QGroupBox(self.page_5)
        self.groupBox_2.setObjectName("groupBox_2")
        self.gridlayout8 = QtWidgets.QGridLayout(self.groupBox_2)
        self.gridlayout8.setObjectName("gridlayout8")
        self.label_6 = QtWidgets.QLabel(self.groupBox_2)
        self.label_6.setObjectName("label_6")
        self.gridlayout8.addWidget(self.label_6, 0, 0, 1, 1)
        self.KeyLineEdit = QtWidgets.QLineEdit(self.groupBox_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.KeyLineEdit.sizePolicy().hasHeightForWidth())
        self.KeyLineEdit.setSizePolicy(sizePolicy)
        self.KeyLineEdit.setObjectName("KeyLineEdit")
        self.gridlayout8.addWidget(self.KeyLineEdit, 0, 1, 1, 1)
        self.KeysIcon = QtWidgets.QLabel(self.groupBox_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.KeysIcon.sizePolicy().hasHeightForWidth())
        self.KeysIcon.setSizePolicy(sizePolicy)
        self.KeysIcon.setMinimumSize(QtCore.QSize(32, 32))
        self.KeysIcon.setMaximumSize(QtCore.QSize(32, 32))
        self.KeysIcon.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.KeysIcon.setText("")
        self.KeysIcon.setObjectName("KeysIcon")
        self.gridlayout8.addWidget(self.KeysIcon, 0, 2, 1, 1)
        self.ShowKeyCheckBox = QtWidgets.QCheckBox(self.groupBox_2)
        self.ShowKeyCheckBox.setObjectName("ShowKeyCheckBox")
        self.gridlayout8.addWidget(self.ShowKeyCheckBox, 1, 1, 1, 2)
        self.gridlayout6.addWidget(self.groupBox_2, 5, 0, 1, 2)
        spacerItem8 = QtWidgets.QSpacerItem(638, 81, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridlayout6.addItem(spacerItem8, 6, 1, 1, 1)
        self.ConfigureIcon = QtWidgets.QLabel(self.page_5)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.ConfigureIcon.sizePolicy().hasHeightForWidth())
        self.ConfigureIcon.setSizePolicy(sizePolicy)
        self.ConfigureIcon.setMinimumSize(QtCore.QSize(16, 16))
        self.ConfigureIcon.setMaximumSize(QtCore.QSize(16, 16))
        self.ConfigureIcon.setText("")
        self.ConfigureIcon.setObjectName("ConfigureIcon")
        self.gridlayout6.addWidget(self.ConfigureIcon, 7, 0, 1, 1)
        self.label_7 = QtWidgets.QLabel(self.page_5)
        self.label_7.setObjectName("label_7")
        self.gridlayout6.addWidget(self.label_7, 7, 1, 1, 1)
        self.StackedWidget.addWidget(self.page_5)
        self.page = QtWidgets.QWidget()
        self.page.setObjectName("page")
        self.gridlayout9 = QtWidgets.QGridLayout(self.page)
        self.gridlayout9.setObjectName("gridlayout9")
        self.label_16 = QtWidgets.QLabel(self.page)
        font = QtGui.QFont()
        font.setPointSize(16)
        self.label_16.setFont(font)
        self.label_16.setObjectName("label_16")
        self.gridlayout9.addWidget(self.label_16, 0, 0, 1, 1)
        self.line_5 = QtWidgets.QFrame(self.page)
        self.line_5.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_5.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_5.setObjectName("line_5")
        self.gridlayout9.addWidget(self.line_5, 1, 0, 1, 1)
        self.groupBox_4 = QtWidgets.QGroupBox(self.page)
        self.groupBox_4.setObjectName("groupBox_4")
        self.gridlayout10 = QtWidgets.QGridLayout(self.groupBox_4)
        self.gridlayout10.setObjectName("gridlayout10")
        self.label_8 = QtWidgets.QLabel(self.groupBox_4)
        self.label_8.setObjectName("label_8")
        self.gridlayout10.addWidget(self.label_8, 0, 0, 1, 1)
        self.SSIDLabel_2 = QtWidgets.QLabel(self.groupBox_4)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.SSIDLabel_2.sizePolicy().hasHeightForWidth())
        self.SSIDLabel_2.setSizePolicy(sizePolicy)
        self.SSIDLabel_2.setObjectName("SSIDLabel_2")
        self.gridlayout10.addWidget(self.SSIDLabel_2, 0, 1, 1, 1)
        self.hboxlayout3 = QtWidgets.QHBoxLayout()
        self.hboxlayout3.setObjectName("hboxlayout3")
        self.SignalStrengthIcon = QtWidgets.QLabel(self.groupBox_4)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.SignalStrengthIcon.sizePolicy().hasHeightForWidth())
        self.SignalStrengthIcon.setSizePolicy(sizePolicy)
        self.SignalStrengthIcon.setMinimumSize(QtCore.QSize(34, 20))
        self.SignalStrengthIcon.setMaximumSize(QtCore.QSize(34, 20))
        self.SignalStrengthIcon.setObjectName("SignalStrengthIcon")
        self.hboxlayout3.addWidget(self.SignalStrengthIcon)
        self.SignalStrengthLabel = QtWidgets.QLabel(self.groupBox_4)
        self.SignalStrengthLabel.setObjectName("SignalStrengthLabel")
        self.hboxlayout3.addWidget(self.SignalStrengthLabel)
        self.gridlayout10.addLayout(self.hboxlayout3, 0, 2, 1, 1)
        self.label_9 = QtWidgets.QLabel(self.groupBox_4)
        self.label_9.setObjectName("label_9")
        self.gridlayout10.addWidget(self.label_9, 1, 0, 1, 1)
        self.AddressModeLabel = QtWidgets.QLabel(self.groupBox_4)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.AddressModeLabel.sizePolicy().hasHeightForWidth())
        self.AddressModeLabel.setSizePolicy(sizePolicy)
        self.AddressModeLabel.setObjectName("AddressModeLabel")
        self.gridlayout10.addWidget(self.AddressModeLabel, 1, 1, 1, 1)
        self.label_12 = QtWidgets.QLabel(self.groupBox_4)
        self.label_12.setObjectName("label_12")
        self.gridlayout10.addWidget(self.label_12, 2, 0, 1, 1)
        self.HostnameLabel = QtWidgets.QLabel(self.groupBox_4)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.HostnameLabel.sizePolicy().hasHeightForWidth())
        self.HostnameLabel.setSizePolicy(sizePolicy)
        self.HostnameLabel.setObjectName("HostnameLabel")
        self.gridlayout10.addWidget(self.HostnameLabel, 2, 1, 1, 1)
        self.label_10 = QtWidgets.QLabel(self.groupBox_4)
        self.label_10.setObjectName("label_10")
        self.gridlayout10.addWidget(self.label_10, 3, 0, 1, 1)
        self.IPAddressLabel = QtWidgets.QLabel(self.groupBox_4)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.IPAddressLabel.sizePolicy().hasHeightForWidth())
        self.IPAddressLabel.setSizePolicy(sizePolicy)
        self.IPAddressLabel.setObjectName("IPAddressLabel")
        self.gridlayout10.addWidget(self.IPAddressLabel, 3, 1, 1, 1)
        self.label_11 = QtWidgets.QLabel(self.groupBox_4)
        self.label_11.setObjectName("label_11")
        self.gridlayout10.addWidget(self.label_11, 4, 0, 1, 1)
        self.GatewayLabel = QtWidgets.QLabel(self.groupBox_4)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.GatewayLabel.sizePolicy().hasHeightForWidth())
        self.GatewayLabel.setSizePolicy(sizePolicy)
        self.GatewayLabel.setObjectName("GatewayLabel")
        self.gridlayout10.addWidget(self.GatewayLabel, 4, 1, 1, 1)
        self.label_13 = QtWidgets.QLabel(self.groupBox_4)
        self.label_13.setObjectName("label_13")
        self.gridlayout10.addWidget(self.label_13, 5, 0, 1, 1)
        self.DNSLabel = QtWidgets.QLabel(self.groupBox_4)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.DNSLabel.sizePolicy().hasHeightForWidth())
        self.DNSLabel.setSizePolicy(sizePolicy)
        self.DNSLabel.setObjectName("DNSLabel")
        self.gridlayout10.addWidget(self.DNSLabel, 5, 1, 1, 1)
        self.gridlayout9.addWidget(self.groupBox_4, 2, 0, 1, 1)
        self.groupBox_5 = QtWidgets.QGroupBox(self.page)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(self.groupBox_5.sizePolicy().hasHeightForWidth())
        self.groupBox_5.setSizePolicy(sizePolicy)
        self.groupBox_5.setObjectName("groupBox_5")
        self.gridlayout11 = QtWidgets.QGridLayout(self.groupBox_5)
        self.gridlayout11.setObjectName("gridlayout11")
        self.ExitIcon = QtWidgets.QLabel(self.groupBox_5)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.ExitIcon.sizePolicy().hasHeightForWidth())
        self.ExitIcon.setSizePolicy(sizePolicy)
        self.ExitIcon.setMinimumSize(QtCore.QSize(16, 16))
        self.ExitIcon.setMaximumSize(QtCore.QSize(16, 16))
        self.ExitIcon.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.ExitIcon.setText("")
        self.ExitIcon.setObjectName("ExitIcon")
        self.gridlayout11.addWidget(self.ExitIcon, 0, 0, 1, 1)
        self.ExitLabel = QtWidgets.QLabel(self.groupBox_5)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.ExitLabel.sizePolicy().hasHeightForWidth())
        self.ExitLabel.setSizePolicy(sizePolicy)
        self.ExitLabel.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.ExitLabel.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignTop)
        self.ExitLabel.setWordWrap(True)
        self.ExitLabel.setObjectName("ExitLabel")
        self.gridlayout11.addWidget(self.ExitLabel, 0, 1, 2, 2)
        spacerItem9 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridlayout11.addItem(spacerItem9, 1, 0, 1, 1)
        spacerItem10 = QtWidgets.QSpacerItem(501, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridlayout11.addItem(spacerItem10, 2, 0, 1, 2)
        self.hboxlayout4 = QtWidgets.QHBoxLayout()
        self.hboxlayout4.setObjectName("hboxlayout4")
        self.PageLabel2 = QtWidgets.QLabel(self.groupBox_5)
        self.PageLabel2.setObjectName("PageLabel2")
        self.hboxlayout4.addWidget(self.PageLabel2)
        self.PageSpinBox = QtWidgets.QSpinBox(self.groupBox_5)
        self.PageSpinBox.setMinimum(1)
        self.PageSpinBox.setObjectName("PageSpinBox")
        self.hboxlayout4.addWidget(self.PageSpinBox)
        self.PageLabel = QtWidgets.QLabel(self.groupBox_5)
        self.PageLabel.setObjectName("PageLabel")
        self.hboxlayout4.addWidget(self.PageLabel)
        self.gridlayout11.addLayout(self.hboxlayout4, 2, 2, 1, 1)
        self.gridlayout9.addWidget(self.groupBox_5, 3, 0, 1, 1)
        spacerItem11 = QtWidgets.QSpacerItem(664, 20, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridlayout9.addItem(spacerItem11, 4, 0, 1, 1)
        self.StackedWidget.addWidget(self.page)
        self.gridlayout.addWidget(self.StackedWidget, 0, 0, 1, 5)
        self.StepText = QtWidgets.QLabel(Dialog)
        self.StepText.setObjectName("StepText")
        self.gridlayout.addWidget(self.StepText, 1, 0, 1, 1)
        spacerItem12 = QtWidgets.QSpacerItem(181, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridlayout.addItem(spacerItem12, 1, 1, 1, 1)
        self.BackButton = QtWidgets.QPushButton(Dialog)
        self.BackButton.setObjectName("BackButton")
        self.gridlayout.addWidget(self.BackButton, 1, 2, 1, 1)
        self.NextButton = QtWidgets.QPushButton(Dialog)
        self.NextButton.setObjectName("NextButton")
        self.gridlayout.addWidget(self.NextButton, 1, 3, 1, 1)
        self.CancelButton = QtWidgets.QPushButton(Dialog)
        self.CancelButton.setObjectName("CancelButton")
        self.gridlayout.addWidget(self.CancelButton, 1, 4, 1, 1)

        self.retranslateUi(Dialog)
        self.StackedWidget.setCurrentIndex(0)
        QtCore.QMetaObject.connectSlotsByName(Dialog)

    def retranslateUi(self, Dialog):
        _translate = QtCore.QCoreApplication.translate
        Dialog.setWindowTitle(_translate("Dialog", "HP Device Manager - Wifi Setup"))
        self.label.setText(_translate("Dialog", "Wireless (Wifi/802.11) Setup"))
        self.MainTitleLabel.setText(_translate("Dialog", "<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'Sans Serif\'; font-size:9pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">This utility allows you configure your wireless capable printer using a temporary USB connection. You will be prompted to disconnect the USB cable once wireless network setup is complete.</p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-style:italic;\">Note: Only select wireless capable printers are supported by this utility.</span></p></body></html>"))
        self.label_14.setText(_translate("Dialog", "<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'Sans Serif\'; font-size:9pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Please plug-in your wireless capable printer at this time (using a USB cable) and click<span style=\" font-style:italic;\"> Next &gt;</span> to continue.</p></body></html>"))
        self.label_4.setText(_translate("Dialog", "Select From Discovered Wireless Capable Devices"))
        self.DevicesTableWidget.setSortingEnabled(False)
        self.DevicesFoundLabel.setText(_translate("Dialog", "Found 0 wireless capable devices on the USB bus."))
        self.RefreshButton.setText(_translate("Dialog", "Refresh"))
        self.label_5.setText(_translate("Dialog", "Find and Select a Wireless Network"))
        self.groupBox_3.setTitle(_translate("Dialog", "Find Wireless Network"))
        self.UndirectedRadioButton.setText(_translate("Dialog", "Search for wireless networks automatically"))
        self.DirectedRadioButton.setText(_translate("Dialog", "Enter the name (SSID) of a known wireless network:"))
        self.SearchPushButton.setText(_translate("Dialog", "Search"))
        self.SelectSSIDGroupBox.setTitle(_translate("Dialog", "Wireless Networks"))
        self.ShowExtendedCheckBox.setText(_translate("Dialog", "Show extended information"))
        self.NetworksFoundLabel.setText(_translate("Dialog", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'Sans\'; font-size:10pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Found %1 wireless networks. Click <span style=\" font-style:italic;\">Search</span> to perform another search.</p></body></html>"))
        self.label_15.setText(_translate("Dialog", "Configure Wireless"))
        self.label_3.setText(_translate("Dialog", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'Sans\'; font-size:10pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-family:\'Sans Serif\';\">Wireless Network Name (SSID):</span></p></body></html>"))
        self.SSIDLabel.setText(_translate("Dialog", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'Sans\'; font-size:10pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-family:\'Sans Serif\';\">(unknown)</span></p></body></html>"))
        self.groupBox.setTitle(_translate("Dialog", "Wireless Security Type"))
        self.WEPRadioButton.setText(_translate("Dialog", "WEP (Wired Equivalent Privacy)"))
        self.WPARadioButton.setText(_translate("Dialog", "WPA (Wi-Fi Protected Access)"))
        self.groupBox_2.setTitle(_translate("Dialog", "Wireless Security Key"))
        self.label_6.setText(_translate("Dialog", "Key:"))
        self.ShowKeyCheckBox.setText(_translate("Dialog", "Show key"))
        self.label_7.setText(_translate("Dialog", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'Sans\'; font-size:10pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-family:\'Sans Serif\'; font-size:9pt;\">Enter the security key for the network, and click </span><span style=\" font-family:\'Sans Serif\'; font-size:9pt; font-style:italic;\">Connect</span><span style=\" font-family:\'Sans Serif\'; font-size:9pt;\"> to continue.</span></p></body></html>"))
        self.label_16.setText(_translate("Dialog", "Wireless Configuration Results"))
        self.groupBox_4.setTitle(_translate("Dialog", "Wireless Configuration"))
        self.label_8.setText(_translate("Dialog", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'Sans\'; font-size:10pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-family:\'Sans Serif\'; font-size:9pt;\">Network:</span></p></body></html>"))
        self.SSIDLabel_2.setText(_translate("Dialog", "TextLabel"))
        self.SignalStrengthIcon.setText(_translate("Dialog", "(icon)"))
        self.SignalStrengthLabel.setText(_translate("Dialog", "0/5 (0dBm)"))
        self.label_9.setText(_translate("Dialog", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'Sans\'; font-size:10pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-family:\'Sans Serif\'; font-size:9pt;\">Address Mode:</span></p></body></html>"))
        self.AddressModeLabel.setText(_translate("Dialog", "TextLabel"))
        self.label_12.setText(_translate("Dialog", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'Sans\'; font-size:10pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-family:\'Sans Serif\'; font-size:9pt;\">Hostname:</span></p></body></html>"))
        self.HostnameLabel.setText(_translate("Dialog", "TextLabel"))
        self.label_10.setText(_translate("Dialog", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'Sans\'; font-size:10pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-family:\'Sans Serif\'; font-size:9pt;\">IP Address:</span></p></body></html>"))
        self.IPAddressLabel.setText(_translate("Dialog", "TextLabel"))
        self.label_11.setText(_translate("Dialog", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'Sans\'; font-size:10pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-family:\'Sans Serif\'; font-size:9pt;\">Gateway Address:</span></p></body></html>"))
        self.GatewayLabel.setText(_translate("Dialog", "TextLabel"))
        self.label_13.setText(_translate("Dialog", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'Sans\'; font-size:10pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-family:\'Sans Serif\'; font-size:9pt;\">DNS Address:</span></p></body></html>"))
        self.DNSLabel.setText(_translate("Dialog", "TextLabel"))
        self.groupBox_5.setTitle(_translate("Dialog", "Messages"))
        self.ExitLabel.setText(_translate("Dialog", "TextLabel"))
        self.PageLabel2.setText(_translate("Dialog", "Message:"))
        self.PageLabel.setText(_translate("Dialog", "of XXX"))
        self.StepText.setText(_translate("Dialog", "Step %1 of %2"))
        self.BackButton.setText(_translate("Dialog", "< Back"))
        self.NextButton.setText(_translate("Dialog", "Next >"))
        self.CancelButton.setText(_translate("Dialog", "Cancel"))

from .readonlyradiobutton import ReadOnlyRadioButton
