# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'ui5/plugindialog_base.ui'
#
# Created by: PyQt5 UI code generator 5.4.2
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Dialog(object):
    def setupUi(self, Dialog):
        Dialog.setObjectName("Dialog")
        Dialog.resize(700, 500)
        self.gridlayout = QtWidgets.QGridLayout(Dialog)
        self.gridlayout.setObjectName("gridlayout")
        self.StackedWidget = QtWidgets.QStackedWidget(Dialog)
        self.StackedWidget.setObjectName("StackedWidget")
        self.page = QtWidgets.QWidget()
        self.page.setObjectName("page")
        self.gridlayout1 = QtWidgets.QGridLayout(self.page)
        self.gridlayout1.setObjectName("gridlayout1")
        self.label = QtWidgets.QLabel(self.page)
        font = QtGui.QFont()
        font.setPointSize(16)
        self.label.setFont(font)
        self.label.setObjectName("label")
        self.gridlayout1.addWidget(self.label, 0, 0, 1, 1)
        self.line = QtWidgets.QFrame(self.page)
        self.line.setFrameShape(QtWidgets.QFrame.HLine)
        self.line.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line.setObjectName("line")
        self.gridlayout1.addWidget(self.line, 1, 0, 1, 2)
        self.TitleLabel = QtWidgets.QLabel(self.page)
        self.TitleLabel.setWordWrap(True)
        self.TitleLabel.setObjectName("TitleLabel")
        self.gridlayout1.addWidget(self.TitleLabel, 2, 0, 1, 2)
        spacerItem = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridlayout1.addItem(spacerItem, 3, 0, 1, 1)
        self.groupBox = QtWidgets.QGroupBox(self.page)
        self.groupBox.setObjectName("groupBox")
        self.gridlayout2 = QtWidgets.QGridLayout(self.groupBox)
        self.gridlayout2.setObjectName("gridlayout2")
        self.DownloadRadioButton = QtWidgets.QRadioButton(self.groupBox)
        self.DownloadRadioButton.setChecked(True)
        self.DownloadRadioButton.setObjectName("DownloadRadioButton")
        self.gridlayout2.addWidget(self.DownloadRadioButton, 0, 0, 1, 2)
        self.CopyRadioButton = QtWidgets.QRadioButton(self.groupBox)
        self.CopyRadioButton.setEnabled(True)
        self.CopyRadioButton.setObjectName("CopyRadioButton")
        self.gridlayout2.addWidget(self.CopyRadioButton, 1, 0, 1, 2)
        spacerItem1 = QtWidgets.QSpacerItem(20, 20, QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Minimum)
        self.gridlayout2.addItem(spacerItem1, 2, 0, 1, 1)
        self.hboxlayout = QtWidgets.QHBoxLayout()
        self.hboxlayout.setObjectName("hboxlayout")
        self.PathLineEdit = QtWidgets.QLineEdit(self.groupBox)
        self.PathLineEdit.setEnabled(False)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.PathLineEdit.sizePolicy().hasHeightForWidth())
        self.PathLineEdit.setSizePolicy(sizePolicy)
        self.PathLineEdit.setObjectName("PathLineEdit")
        self.hboxlayout.addWidget(self.PathLineEdit)
        self.BrowseToolButton = QtWidgets.QToolButton(self.groupBox)
        self.BrowseToolButton.setEnabled(False)
        self.BrowseToolButton.setText("")
        self.BrowseToolButton.setObjectName("BrowseToolButton")
        self.hboxlayout.addWidget(self.BrowseToolButton)
        self.gridlayout2.addLayout(self.hboxlayout, 2, 1, 1, 1)
        self.SkipRadioButton = QtWidgets.QRadioButton(self.groupBox)
        self.SkipRadioButton.setObjectName("SkipRadioButton")
        self.gridlayout2.addWidget(self.SkipRadioButton, 3, 0, 1, 2)
        self.gridlayout1.addWidget(self.groupBox, 4, 0, 1, 2)
        spacerItem2 = QtWidgets.QSpacerItem(278, 51, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridlayout1.addItem(spacerItem2, 5, 1, 1, 1)
        self.StackedWidget.addWidget(self.page)
        self.gridlayout.addWidget(self.StackedWidget, 0, 0, 1, 5)
        self.line_2 = QtWidgets.QFrame(Dialog)
        self.line_2.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_2.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_2.setObjectName("line_2")
        self.gridlayout.addWidget(self.line_2, 1, 0, 1, 5)
        self.StepText = QtWidgets.QLabel(Dialog)
        self.StepText.setObjectName("StepText")
        self.gridlayout.addWidget(self.StepText, 2, 0, 1, 1)
        spacerItem3 = QtWidgets.QSpacerItem(161, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridlayout.addItem(spacerItem3, 2, 1, 1, 1)
        self.BackButton = QtWidgets.QPushButton(Dialog)
        self.BackButton.setEnabled(False)
        self.BackButton.setObjectName("BackButton")
        self.gridlayout.addWidget(self.BackButton, 2, 2, 1, 1)
        self.NextButton = QtWidgets.QPushButton(Dialog)
        self.NextButton.setObjectName("NextButton")
        self.gridlayout.addWidget(self.NextButton, 2, 3, 1, 1)
        self.CancelButton = QtWidgets.QPushButton(Dialog)
        self.CancelButton.setObjectName("CancelButton")
        self.gridlayout.addWidget(self.CancelButton, 2, 4, 1, 1)

        self.retranslateUi(Dialog)
        self.StackedWidget.setCurrentIndex(0)
        QtCore.QMetaObject.connectSlotsByName(Dialog)

    def retranslateUi(self, Dialog):
        _translate = QtCore.QCoreApplication.translate
        Dialog.setWindowTitle(_translate("Dialog", "HP Device Manager - Plug-in Installer"))
        self.label.setText(_translate("Dialog", "Driver Plug-in Installation"))
        self.TitleLabel.setText(_translate("Dialog", "You may download the plug-in directly from an HP authorized server, or, if you already have a local copy of the plug-in file, you can specify a path to the file."))
        self.groupBox.setTitle(_translate("Dialog", "Plug-in Installation Choice"))
        self.DownloadRadioButton.setText(_translate("Dialog", "Download and install the plug-in from an HP authorized server (recommended)"))
        self.CopyRadioButton.setText(_translate("Dialog", "Select and install an existing local copy of the plug-in file (advanced):"))
        self.BrowseToolButton.setToolTip(_translate("Dialog", "Open a local copy of the plug-in file"))
        self.SkipRadioButton.setText(_translate("Dialog", "Skip installation of the plug-in (not recommended)"))
        self.StepText.setText(_translate("Dialog", "Step %d of %d"))
        self.BackButton.setText(_translate("Dialog", "< Back"))
        self.NextButton.setText(_translate("Dialog", "Next >"))
        self.CancelButton.setText(_translate("Dialog", "Cancel"))

