# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'ui5/sendfaxdialog_base.ui'
#
# Created by: PyQt5 UI code generator 5.4.2
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Dialog(object):
    def setupUi(self, Dialog):
        Dialog.setObjectName("Dialog")
        Dialog.setWindowModality(QtCore.Qt.ApplicationModal)
        Dialog.resize(600, 500)
        self.gridlayout = QtWidgets.QGridLayout(Dialog)
        self.gridlayout.setObjectName("gridlayout")
        self.StackedWidget = QtWidgets.QStackedWidget(Dialog)
        self.StackedWidget.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.StackedWidget.setObjectName("StackedWidget")
        self.SelectFax = QtWidgets.QWidget()
        self.SelectFax.setObjectName("SelectFax")
        self.gridlayout1 = QtWidgets.QGridLayout(self.SelectFax)
        self.gridlayout1.setObjectName("gridlayout1")
        self.label_8 = QtWidgets.QLabel(self.SelectFax)
        font = QtGui.QFont()
        font.setPointSize(16)
        self.label_8.setFont(font)
        self.label_8.setObjectName("label_8")
        self.gridlayout1.addWidget(self.label_8, 0, 0, 1, 1)
        self.line_4 = QtWidgets.QFrame(self.SelectFax)
        self.line_4.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_4.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_4.setObjectName("line_4")
        self.gridlayout1.addWidget(self.line_4, 1, 0, 1, 1)
        self.gridlayout2 = QtWidgets.QGridLayout()
        self.gridlayout2.setObjectName("gridlayout2")
        self.FaxComboBox = PrinterNameComboBox(self.SelectFax)
        self.FaxComboBox.setObjectName("FaxComboBox")
        self.gridlayout2.addWidget(self.FaxComboBox, 0, 0, 1, 3)
        spacerItem = QtWidgets.QSpacerItem(20, 20, QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.Minimum)
        self.gridlayout2.addItem(spacerItem, 1, 0, 1, 1)
        self.FaxOptionsButton = QtWidgets.QPushButton(self.SelectFax)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.FaxOptionsButton.sizePolicy().hasHeightForWidth())
        self.FaxOptionsButton.setSizePolicy(sizePolicy)
        self.FaxOptionsButton.setObjectName("FaxOptionsButton")
        self.gridlayout2.addWidget(self.FaxOptionsButton, 1, 1, 1, 1)
        self.FaxSetupButton = QtWidgets.QPushButton(self.SelectFax)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.FaxSetupButton.sizePolicy().hasHeightForWidth())
        self.FaxSetupButton.setSizePolicy(sizePolicy)
        self.FaxSetupButton.setObjectName("FaxSetupButton")
        self.gridlayout2.addWidget(self.FaxSetupButton, 1, 2, 1, 1)
        self.gridlayout1.addLayout(self.gridlayout2, 2, 0, 1, 1)
        spacerItem1 = QtWidgets.QSpacerItem(564, 221, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridlayout1.addItem(spacerItem1, 3, 0, 1, 1)
        self.label_12 = QtWidgets.QLabel(self.SelectFax)
        self.label_12.setWordWrap(True)
        self.label_12.setObjectName("label_12")
        self.gridlayout1.addWidget(self.label_12, 4, 0, 1, 1)
        self.StackedWidget.addWidget(self.SelectFax)
        self.CoverPage = QtWidgets.QWidget()
        self.CoverPage.setObjectName("CoverPage")
        self.gridlayout3 = QtWidgets.QGridLayout(self.CoverPage)
        self.gridlayout3.setObjectName("gridlayout3")
        self.label_3 = QtWidgets.QLabel(self.CoverPage)
        font = QtGui.QFont()
        font.setPointSize(16)
        self.label_3.setFont(font)
        self.label_3.setObjectName("label_3")
        self.gridlayout3.addWidget(self.label_3, 0, 0, 1, 1)
        self.line_2 = QtWidgets.QFrame(self.CoverPage)
        self.line_2.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_2.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_2.setObjectName("line_2")
        self.gridlayout3.addWidget(self.line_2, 1, 0, 1, 1)
        self.CoverPageGroupBox = QtWidgets.QGroupBox(self.CoverPage)
        self.CoverPageGroupBox.setEnabled(True)
        self.CoverPageGroupBox.setCheckable(True)
        self.CoverPageGroupBox.setChecked(False)
        self.CoverPageGroupBox.setObjectName("CoverPageGroupBox")
        self.gridlayout4 = QtWidgets.QGridLayout(self.CoverPageGroupBox)
        self.gridlayout4.setObjectName("gridlayout4")
        self.gridlayout5 = QtWidgets.QGridLayout()
        self.gridlayout5.setObjectName("gridlayout5")
        self.CoverPageName = QtWidgets.QLabel(self.CoverPageGroupBox)
        self.CoverPageName.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.CoverPageName.setText("")
        self.CoverPageName.setAlignment(QtCore.Qt.AlignCenter)
        self.CoverPageName.setObjectName("CoverPageName")
        self.gridlayout5.addWidget(self.CoverPageName, 0, 0, 1, 4)
        self.CoverPagePreview = QtWidgets.QLabel(self.CoverPageGroupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.CoverPagePreview.sizePolicy().hasHeightForWidth())
        self.CoverPagePreview.setSizePolicy(sizePolicy)
        self.CoverPagePreview.setMinimumSize(QtCore.QSize(134, 192))
        self.CoverPagePreview.setMaximumSize(QtCore.QSize(134, 192))
        self.CoverPagePreview.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.CoverPagePreview.setText("")
        self.CoverPagePreview.setScaledContents(True)
        self.CoverPagePreview.setAlignment(QtCore.Qt.AlignCenter)
        self.CoverPagePreview.setObjectName("CoverPagePreview")
        self.gridlayout5.addWidget(self.CoverPagePreview, 1, 0, 1, 4)
        spacerItem2 = QtWidgets.QSpacerItem(16, 20, QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Minimum)
        self.gridlayout5.addItem(spacerItem2, 2, 0, 1, 1)
        self.PrevCoverPageButton = QtWidgets.QPushButton(self.CoverPageGroupBox)
        self.PrevCoverPageButton.setText("")
        self.PrevCoverPageButton.setObjectName("PrevCoverPageButton")
        self.gridlayout5.addWidget(self.PrevCoverPageButton, 2, 1, 1, 1)
        self.NextCoverPageButton = QtWidgets.QPushButton(self.CoverPageGroupBox)
        self.NextCoverPageButton.setText("")
        self.NextCoverPageButton.setObjectName("NextCoverPageButton")
        self.gridlayout5.addWidget(self.NextCoverPageButton, 2, 2, 1, 1)
        spacerItem3 = QtWidgets.QSpacerItem(31, 20, QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Minimum)
        self.gridlayout5.addItem(spacerItem3, 2, 3, 1, 1)
        spacerItem4 = QtWidgets.QSpacerItem(20, 21, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridlayout5.addItem(spacerItem4, 3, 1, 1, 1)
        self.gridlayout4.addLayout(self.gridlayout5, 0, 0, 2, 1)
        self.vboxlayout = QtWidgets.QVBoxLayout()
        self.vboxlayout.setObjectName("vboxlayout")
        self.label_16 = QtWidgets.QLabel(self.CoverPageGroupBox)
        self.label_16.setObjectName("label_16")
        self.vboxlayout.addWidget(self.label_16)
        self.RegardingEdit = QtWidgets.QLineEdit(self.CoverPageGroupBox)
        self.RegardingEdit.setObjectName("RegardingEdit")
        self.vboxlayout.addWidget(self.RegardingEdit)
        self.gridlayout4.addLayout(self.vboxlayout, 0, 1, 1, 1)
        self.gridlayout6 = QtWidgets.QGridLayout()
        self.gridlayout6.setObjectName("gridlayout6")
        self.label_17 = QtWidgets.QLabel(self.CoverPageGroupBox)
        self.label_17.setObjectName("label_17")
        self.gridlayout6.addWidget(self.label_17, 0, 0, 1, 1)
        self.MessageEdit = QtWidgets.QTextEdit(self.CoverPageGroupBox)
        self.MessageEdit.setObjectName("MessageEdit")
        self.gridlayout6.addWidget(self.MessageEdit, 1, 0, 1, 1)
        self.PreserveFormattingCheckBox = QtWidgets.QCheckBox(self.CoverPageGroupBox)
        self.PreserveFormattingCheckBox.setObjectName("PreserveFormattingCheckBox")
        self.gridlayout6.addWidget(self.PreserveFormattingCheckBox, 2, 0, 1, 1)
        self.gridlayout4.addLayout(self.gridlayout6, 1, 1, 1, 1)
        self.gridlayout3.addWidget(self.CoverPageGroupBox, 2, 0, 1, 1)
        self.label_13 = QtWidgets.QLabel(self.CoverPage)
        self.label_13.setWordWrap(True)
        self.label_13.setObjectName("label_13")
        self.gridlayout3.addWidget(self.label_13, 3, 0, 1, 1)
        self.StackedWidget.addWidget(self.CoverPage)
        self.SelectFiles = QtWidgets.QWidget()
        self.SelectFiles.setObjectName("SelectFiles")
        self.gridlayout7 = QtWidgets.QGridLayout(self.SelectFiles)
        self.gridlayout7.setObjectName("gridlayout7")
        self.label_2 = QtWidgets.QLabel(self.SelectFiles)
        font = QtGui.QFont()
        font.setPointSize(16)
        self.label_2.setFont(font)
        self.label_2.setWordWrap(True)
        self.label_2.setObjectName("label_2")
        self.gridlayout7.addWidget(self.label_2, 0, 0, 1, 1)
        self.line = QtWidgets.QFrame(self.SelectFiles)
        self.line.setFrameShape(QtWidgets.QFrame.HLine)
        self.line.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line.setObjectName("line")
        self.gridlayout7.addWidget(self.line, 1, 0, 1, 1)
        self.FilesTable = FileTable(self.SelectFiles)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.FilesTable.sizePolicy().hasHeightForWidth())
        self.FilesTable.setSizePolicy(sizePolicy)
        self.FilesTable.setObjectName("FilesTable")
        self.gridlayout7.addWidget(self.FilesTable, 2, 0, 1, 1)
        self.FilesPageNote = QtWidgets.QLabel(self.SelectFiles)
        self.FilesPageNote.setWordWrap(True)
        self.FilesPageNote.setObjectName("FilesPageNote")
        self.gridlayout7.addWidget(self.FilesPageNote, 3, 0, 1, 1)
        self.StackedWidget.addWidget(self.SelectFiles)
        self.SelectRecipients = QtWidgets.QWidget()
        self.SelectRecipients.setObjectName("SelectRecipients")
        self.gridlayout8 = QtWidgets.QGridLayout(self.SelectRecipients)
        self.gridlayout8.setObjectName("gridlayout8")
        self.label_4 = QtWidgets.QLabel(self.SelectRecipients)
        font = QtGui.QFont()
        font.setPointSize(16)
        self.label_4.setFont(font)
        self.label_4.setObjectName("label_4")
        self.gridlayout8.addWidget(self.label_4, 0, 0, 1, 1)
        self.line_3 = QtWidgets.QFrame(self.SelectRecipients)
        self.line_3.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_3.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_3.setObjectName("line_3")
        self.gridlayout8.addWidget(self.line_3, 1, 0, 1, 1)
        self.groupBox_4 = QtWidgets.QGroupBox(self.SelectRecipients)
        self.groupBox_4.setObjectName("groupBox_4")
        self.gridlayout9 = QtWidgets.QGridLayout(self.groupBox_4)
        self.gridlayout9.setObjectName("gridlayout9")
        self.RecipientsTable = QtWidgets.QTableWidget(self.groupBox_4)
        self.RecipientsTable.setObjectName("RecipientsTable")
        self.RecipientsTable.setColumnCount(0)
        self.RecipientsTable.setRowCount(0)
        self.gridlayout9.addWidget(self.RecipientsTable, 0, 0, 1, 5)
        self.RemoveRecipientButton = QtWidgets.QPushButton(self.groupBox_4)
        self.RemoveRecipientButton.setEnabled(False)
        self.RemoveRecipientButton.setObjectName("RemoveRecipientButton")
        self.gridlayout9.addWidget(self.RemoveRecipientButton, 1, 0, 1, 1)
        self.MoveRecipientUpButton = QtWidgets.QPushButton(self.groupBox_4)
        self.MoveRecipientUpButton.setEnabled(False)
        self.MoveRecipientUpButton.setObjectName("MoveRecipientUpButton")
        self.gridlayout9.addWidget(self.MoveRecipientUpButton, 1, 1, 1, 1)
        self.MoveRecipientDownButton = QtWidgets.QPushButton(self.groupBox_4)
        self.MoveRecipientDownButton.setEnabled(False)
        self.MoveRecipientDownButton.setObjectName("MoveRecipientDownButton")
        self.gridlayout9.addWidget(self.MoveRecipientDownButton, 1, 2, 1, 1)
        spacerItem5 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridlayout9.addItem(spacerItem5, 1, 3, 1, 1)
        self.FABButton = QtWidgets.QPushButton(self.groupBox_4)
        self.FABButton.setObjectName("FABButton")
        self.gridlayout9.addWidget(self.FABButton, 1, 4, 1, 1)
        self.gridlayout8.addWidget(self.groupBox_4, 2, 0, 1, 1)
        self.groupBox = QtWidgets.QGroupBox(self.SelectRecipients)
        self.groupBox.setObjectName("groupBox")
        self.gridlayout10 = QtWidgets.QGridLayout(self.groupBox)
        self.gridlayout10.setObjectName("gridlayout10")
        self.hboxlayout = QtWidgets.QHBoxLayout()
        self.hboxlayout.setObjectName("hboxlayout")
        self.label = QtWidgets.QLabel(self.groupBox)
        self.label.setObjectName("label")
        self.hboxlayout.addWidget(self.label)
        spacerItem6 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Minimum)
        self.hboxlayout.addItem(spacerItem6)
        self.AddIndividualComboBox = QtWidgets.QComboBox(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.AddIndividualComboBox.sizePolicy().hasHeightForWidth())
        self.AddIndividualComboBox.setSizePolicy(sizePolicy)
        self.AddIndividualComboBox.setObjectName("AddIndividualComboBox")
        self.hboxlayout.addWidget(self.AddIndividualComboBox)
        self.AddIndividualButton = QtWidgets.QPushButton(self.groupBox)
        self.AddIndividualButton.setEnabled(False)
        self.AddIndividualButton.setObjectName("AddIndividualButton")
        self.hboxlayout.addWidget(self.AddIndividualButton)
        self.gridlayout10.addLayout(self.hboxlayout, 0, 0, 1, 1)
        self.hboxlayout1 = QtWidgets.QHBoxLayout()
        self.hboxlayout1.setObjectName("hboxlayout1")
        self.label_5 = QtWidgets.QLabel(self.groupBox)
        self.label_5.setObjectName("label_5")
        self.hboxlayout1.addWidget(self.label_5)
        spacerItem7 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Minimum)
        self.hboxlayout1.addItem(spacerItem7)
        self.AddGroupComboBox = QtWidgets.QComboBox(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.AddGroupComboBox.sizePolicy().hasHeightForWidth())
        self.AddGroupComboBox.setSizePolicy(sizePolicy)
        self.AddGroupComboBox.setObjectName("AddGroupComboBox")
        self.hboxlayout1.addWidget(self.AddGroupComboBox)
        self.AddGroupButton = QtWidgets.QPushButton(self.groupBox)
        self.AddGroupButton.setEnabled(False)
        self.AddGroupButton.setObjectName("AddGroupButton")
        self.hboxlayout1.addWidget(self.AddGroupButton)
        self.gridlayout10.addLayout(self.hboxlayout1, 1, 0, 1, 1)
        self.gridlayout8.addWidget(self.groupBox, 3, 0, 1, 1)
        self.groupBox_3 = QtWidgets.QGroupBox(self.SelectRecipients)
        self.groupBox_3.setObjectName("groupBox_3")
        self.gridlayout11 = QtWidgets.QGridLayout(self.groupBox_3)
        self.gridlayout11.setObjectName("gridlayout11")
        self.hboxlayout2 = QtWidgets.QHBoxLayout()
        self.hboxlayout2.setObjectName("hboxlayout2")
        self.label_6 = QtWidgets.QLabel(self.groupBox_3)
        self.label_6.setObjectName("label_6")
        self.hboxlayout2.addWidget(self.label_6)
        self.QuickAddNameEdit = QtWidgets.QLineEdit(self.groupBox_3)
        self.QuickAddNameEdit.setObjectName("QuickAddNameEdit")
        self.hboxlayout2.addWidget(self.QuickAddNameEdit)
        self.label_7 = QtWidgets.QLabel(self.groupBox_3)
        self.label_7.setObjectName("label_7")
        self.hboxlayout2.addWidget(self.label_7)
        self.QuickAddFaxEdit = QtWidgets.QLineEdit(self.groupBox_3)
        self.QuickAddFaxEdit.setObjectName("QuickAddFaxEdit")
        self.hboxlayout2.addWidget(self.QuickAddFaxEdit)
        self.QuickAddButton = QtWidgets.QPushButton(self.groupBox_3)
        self.QuickAddButton.setEnabled(False)
        self.QuickAddButton.setObjectName("QuickAddButton")
        self.hboxlayout2.addWidget(self.QuickAddButton)
        self.gridlayout11.addLayout(self.hboxlayout2, 0, 0, 1, 1)
        self.gridlayout8.addWidget(self.groupBox_3, 4, 0, 1, 1)
        self.StackedWidget.addWidget(self.SelectRecipients)
        self.SendFax = QtWidgets.QWidget()
        self.SendFax.setObjectName("SendFax")
        self.gridlayout12 = QtWidgets.QGridLayout(self.SendFax)
        self.gridlayout12.setObjectName("gridlayout12")
        self.label_9 = QtWidgets.QLabel(self.SendFax)
        font = QtGui.QFont()
        font.setPointSize(16)
        self.label_9.setFont(font)
        self.label_9.setObjectName("label_9")
        self.gridlayout12.addWidget(self.label_9, 0, 0, 1, 1)
        self.line_5 = QtWidgets.QFrame(self.SendFax)
        self.line_5.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_5.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_5.setObjectName("line_5")
        self.gridlayout12.addWidget(self.line_5, 1, 0, 1, 1)
        self.label_10 = QtWidgets.QLabel(self.SendFax)
        self.label_10.setObjectName("label_10")
        self.gridlayout12.addWidget(self.label_10, 2, 0, 1, 1)
        self.StatusList = QtWidgets.QListWidget(self.SendFax)
        self.StatusList.setObjectName("StatusList")
        self.gridlayout12.addWidget(self.StatusList, 3, 0, 1, 1)
        self.label_15 = QtWidgets.QLabel(self.SendFax)
        self.label_15.setObjectName("label_15")
        self.gridlayout12.addWidget(self.label_15, 4, 0, 1, 1)
        self.StackedWidget.addWidget(self.SendFax)
        self.gridlayout.addWidget(self.StackedWidget, 0, 0, 1, 5)
        self.line_6 = QtWidgets.QFrame(Dialog)
        self.line_6.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_6.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_6.setObjectName("line_6")
        self.gridlayout.addWidget(self.line_6, 1, 0, 1, 5)
        self.StepText = QtWidgets.QLabel(Dialog)
        self.StepText.setObjectName("StepText")
        self.gridlayout.addWidget(self.StepText, 2, 0, 1, 1)
        spacerItem8 = QtWidgets.QSpacerItem(231, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridlayout.addItem(spacerItem8, 2, 1, 1, 1)
        self.BackButton = QtWidgets.QPushButton(Dialog)
        self.BackButton.setObjectName("BackButton")
        self.gridlayout.addWidget(self.BackButton, 2, 2, 1, 1)
        self.NextButton = QtWidgets.QPushButton(Dialog)
        self.NextButton.setObjectName("NextButton")
        self.gridlayout.addWidget(self.NextButton, 2, 3, 1, 1)
        self.CancelButton = QtWidgets.QPushButton(Dialog)
        self.CancelButton.setObjectName("CancelButton")
        self.gridlayout.addWidget(self.CancelButton, 2, 4, 1, 1)

        self.retranslateUi(Dialog)
        self.StackedWidget.setCurrentIndex(1)
        QtCore.QMetaObject.connectSlotsByName(Dialog)

    def retranslateUi(self, Dialog):
        _translate = QtCore.QCoreApplication.translate
        Dialog.setWindowTitle(_translate("Dialog", "HP Device Manager - Send Fax"))
        self.label_8.setText(_translate("Dialog", "Select Fax"))
        self.FaxOptionsButton.setText(_translate("Dialog", "Fax Settings..."))
        self.FaxSetupButton.setText(_translate("Dialog", "Fax Device Setup..."))
        self.label_12.setText(_translate("Dialog", "<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'Sans Serif\'; font-size:9pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Select the desired fax printer queue and click <span style=\" font-style:italic;\">Next</span> to continue. Note: Once you continue to the next step, you will not be able to change to a different fax queue.</p></body></html>"))
        self.label_3.setText(_translate("Dialog", "Select and Edit Fax Coverpage (Optional)"))
        self.CoverPageGroupBox.setTitle(_translate("Dialog", "Include Coverpage"))
        self.label_16.setText(_translate("Dialog", "Regarding:"))
        self.label_17.setText(_translate("Dialog", "Optional Message: (max. 2000 characters or 32 preformatted lines)"))
        self.PreserveFormattingCheckBox.setText(_translate("Dialog", "Preformatted (preserve formatting)"))
        self.label_13.setText(_translate("Dialog", "<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'DejaVu Sans\'; font-size:10pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:\'Sans Serif\'; font-size:9pt;\">Check<span style=\" font-style:italic;\"> Include Coverpage </span>to add a coverpage to this fax. To continue without a coverpage, click <span style=\" font-style:italic;\">Next &gt;</span>.</p></body></html>"))
        self.label_2.setText(_translate("Dialog", "Select Files to Send"))
        self.FilesPageNote.setText(_translate("Dialog", "Note: You may also add files to the fax by printing from any application to the \'%1\' fax printer."))
        self.label_4.setText(_translate("Dialog", "Select Fax Recipients"))
        self.groupBox_4.setTitle(_translate("Dialog", "Recipients"))
        self.RemoveRecipientButton.setText(_translate("Dialog", "Remove"))
        self.MoveRecipientUpButton.setText(_translate("Dialog", "Move Up"))
        self.MoveRecipientDownButton.setText(_translate("Dialog", "Move Down"))
        self.FABButton.setText(_translate("Dialog", "Fax Address Book..."))
        self.groupBox.setTitle(_translate("Dialog", "Add Recipients or Groups from the Fax Address Book"))
        self.label.setText(_translate("Dialog", "Add an individual:"))
        self.AddIndividualButton.setText(_translate("Dialog", "Add"))
        self.label_5.setText(_translate("Dialog", "Add a group:"))
        self.AddGroupButton.setText(_translate("Dialog", "Add"))
        self.groupBox_3.setTitle(_translate("Dialog", "Quick Add an Individual Recipient (recipient will automatically be added to fax address book)"))
        self.label_6.setText(_translate("Dialog", "Name:"))
        self.label_7.setText(_translate("Dialog", "Fax Number:"))
        self.QuickAddButton.setText(_translate("Dialog", "Add"))
        self.label_9.setText(_translate("Dialog", "Send Fax"))
        self.label_10.setText(_translate("Dialog", "Status:"))
        self.label_15.setText(_translate("Dialog", "<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'Sans Serif\'; font-size:9pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Click <span style=\" font-style:italic;\">Send Fax</span> to start the fax transmission.</p></body></html>"))
        self.StepText.setText(_translate("Dialog", "Step %1 of %2"))
        self.BackButton.setText(_translate("Dialog", "< Back"))
        self.NextButton.setText(_translate("Dialog", "Next >"))
        self.CancelButton.setText(_translate("Dialog", "Cancel"))

from .filetable import FileTable
from .printernamecombobox import PrinterNameComboBox
